@@ -6,6 +6,7 @@ Created on Tue May  4 15:59:03 2021
 from math import log
 import time
 import sys
+from types import GeneratorType
 
 
 class ProgressBar:
@@ -35,7 +36,7 @@ class ProgressBar:
             Whether or not to use the average of the items per second. The default is (False, 1000).
         '''
         self.completed = completed
-        if hasattr(items, '__iter__'):
+        if hasattr(items, '__iter__') and not isinstance(items, GeneratorType):
             self.items = len(items)
             self.enums = items
         else:
